==> kst-1.1.0_dr1.tar.gz: kst-1.1.0_dr1/kst/kst/kstmetaplot.cpp <==
/***************************************************************************
                              kstmetaplot.cpp
                             -------------------
    begin                : Mar 11, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kstmetaplot.h"


KstMetaPlot::KstMetaPlot(const QString& type) : KstBorderedViewObject(type) {
}


KstMetaPlot::KstMetaPlot(QDomElement& e) : KstBorderedViewObject(e) {
}


KstMetaPlot::~KstMetaPlot() {
}


KstObject::UpdateType KstMetaPlot::update() {
  return NO_CHANGE;
}


void KstMetaPlot::save(QTextStream& ts, const QString& indent) {
  KstBorderedViewObject::save(ts, indent);
}


void KstMetaPlot::saveTag(QTextStream& ts, const QString& indent) {
  KstBorderedViewObject::saveTag(ts, indent);
}


#include "kstmetaplot.moc"
// vim: ts=2 sw=2 et

==> kst-1.2.0dr1.tar.gz: kst-1.2.0dr1/kst/kst/kstmetaplot.cpp <==
/***************************************************************************
                              kstmetaplot.cpp
                             -------------------
    begin                : Mar 11, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kstmetaplot.h"


KstMetaPlot::KstMetaPlot(const QString& type)
: KstBorderedViewObject(type) {
  setFollowsFlow(true);
}


KstMetaPlot::KstMetaPlot(const QDomElement& e)
: KstBorderedViewObject(e) {
  setFollowsFlow(true);
}


KstMetaPlot::KstMetaPlot(const KstMetaPlot& metaPlot)
: KstBorderedViewObject(metaPlot) {
}


KstMetaPlot::~KstMetaPlot() {
}


void KstMetaPlot::save(QTextStream& ts, const QString& indent) {
  KstBorderedViewObject::save(ts, indent);
}


#include "kstmetaplot.moc"
// vim: ts=2 sw=2 et
